@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2015-07-20'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2015-07-30'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use 5.010001;
 use strict;
@@ -141,7 +141,7 @@ sub munge_files {
         $self->log_debug(["Adding prereq to %s", $perimod]);
         $self->zilla->register_prereqs(
             {phase => $res->[3]{'func.cmdline_module_inlined'} ?
-                 'build' : 'runtime'},
+                 'develop' : 'runtime'},
             $perimod => $res->[3]{'func.cmdline_module_version'});
         $mem{$perimod}++;
 
@@ -187,7 +187,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.21 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-07-20.
+This document describes version 0.22 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2015-07-30.
 
 =head1 SYNOPSIS
 
